#!/bin/bash

if ! grep -q boot_external /proc/cmdline ; then
	exit 0
fi

if ! test -e /dev/mmcblk0 ; then
	echo 255 >/sys/class/leds/blue/brightness
	sleep 1
	reboot
	exit 1
fi

for led in orange ; do
	echo 255 >/sys/class/leds/$led/brightness
done

# disable watchdog
echo V >/dev/watchdog

# determine how many bytes to copy
unit=$(fdisk -l /dev/mmcblk1 2>&1 | grep Units | sed -e 's/.* \([0-9]*\) bytes/\1/g')
units=$(fdisk -l /dev/mmcblk1 2>&1 | grep /dev/mmcblk1p8 | sed -e 's/[^ ]* [ ]* \([0-9]*\).*/\1/g')
size=$(($unit*($units+1)))

echo We need to copy $size bytes

# delete old partition table
partx -d /dev/mmcblk0

success=0
if ddrescue --block-size=4096 -s $size --verbose --force /dev/mmcblk1 /dev/mmcblk0 ; then
	success=1
fi

# delete partitions 8-10, if they are already there
fdisk /dev/mmcblk0 <<EOF
d
8
w
EOF

fdisk /dev/mmcblk0 <<EOF
d
8
w
EOF

fdisk /dev/mmcblk0 <<EOF
d
8
w
EOF

# now re-create them
fdisk /dev/mmcblk0 <<EOF
n

+512M
n

+32M
n



w
EOF

# re-read partition table
partx -d /dev/mmcblk0
partx -a /dev/mmcblk0

# create all needed filesystems
mkfs.ext4 /dev/mmcblk0p8
mkfs.ext4 /dev/mmcblk0p9
mkfs.ext4 /dev/mmcblk0p10

/sbin/update-boot-to-gui.sh /dev/mmcblk0p2

leds="orange"

value=255
while true ; do
	case $value in 
255)
	value=0
	;;
0)
	value=255
	;;
	esac
	for led in $leds; do
		echo $value >/sys/class/leds/$led/brightness
	done
	if [ "$success" == "1" ] ; then
		sleep 1
	else
		for a in $(seq 1 50) ; do
			echo >/dev/null
		done
	fi
done
