#!/bin/bash

set -e

RESCUE_KERNEL_LOC=/dev/mmcblk0p3
RESCUE_ROOTFS_LOC=/dev/mmcblk0p6
RESCUE_ROOTFS_MNT=/tmp/rootfs
UPDATE_SRC=$1

grep -q boot_gui /proc/cmdline || exit 1

function log()
{
	logger "$@"
	echo "$@" >/dev/console
}

grep -q $RESCUE_ROOTFS_LOC /proc/mounts && umount -lf $RESCUE_ROOTFS_LOC

if [ ! -d "$UPDATE_SRC" ] ; then
	log "invalid filename $UPDATE_SRC"
	exit 1
fi
                
log "Updating kernel"
dd if=${UPDATE_SRC}/images/linuximage of=$RESCUE_KERNEL_LOC bs=512K

echo "Creating rescue fs"
mkfs.ext4 $RESCUE_ROOTFS_LOC

if [ ! -d $RESCUE_ROOTFS_MNT ]; then
	mkdir -p $RESCUE_ROOTFS_MNT
fi

mount $RESCUE_ROOTFS_LOC $RESCUE_ROOTFS_MNT

log "Extracting rescue fs"
tar -xzf ${UPDATE_SRC}/images/rescue.tgz -C $RESCUE_ROOTFS_MNT

umount $RESCUE_ROOTFS_LOC

/sbin/update-boot-to-rescue.sh

log "Rescue update finished"

exit 0

