#!/bin/bash

set -e

KERNEL_LOC=/dev/mmcblk0p5
ROOTFS_LOC=/dev/mmcblk0p7
ROOTFS_MNT=/tmp/rootfs
UPDATE_MNT=/update
UPDATE_SRC=/update/gui

grep -q boot_rescue /proc/cmdline || exit 0

systemctl stop boot-animation
systemctl start update-animation &

grep -q "$UPDATE_MNT" /proc/mounts || mount "$UPDATE_MNT"
grep -q "$ROOTFS_MNT" /proc/mounts && umount "$ROOTFS_MNT"

function log()
{
	logger "$@"
	echo "$@" >/dev/console
}

function exit_trap()
{
	umount -fl "$UPDATE_MNT"
	umount -fl "$ROOTFS_MNT"
}

trap exit_trap ERR TERM INT

if [ ! -d "$UPDATE_SRC" ] ; then
	# workaround for dir rename
	if [ ! -d "/update/files" ] ; then
		log "invalid filename $UPDATE_SRC"
		sleep 60
		reboot
		exit 1
	else
		mv /update/files "$UPDATE_SRC"
	fi
fi

echo V >/dev/watchdog

killall blinking-sequence.sh || true

/sbin/blinking-sequence.sh /usr/share/blinking/update &
                
log "Updating kernel"
dd if=${UPDATE_SRC}/images/linuximage of=$KERNEL_LOC bs=512K

echo "Creating root fs"
mkfs.ext4 $ROOTFS_LOC

if [ ! -d $ROOTFS_MNT ]; then
	mkdir -p $ROOTFS_MNT
fi

mount $ROOTFS_LOC $ROOTFS_MNT

log "Extracting root fs"
tar -xzf ${UPDATE_SRC}/images/root.tgz -C $ROOTFS_MNT

umount $ROOTFS_LOC

# clear old project data
rm -rf /data/projects /data/gui /data/export /data/import || true

/sbin/update-boot-to-gui.sh

log "GUI update finished"

reboot

exit 0

